pub struct DatabaseCreds {
pub username: String,
pub password: String,
pub duration: Duration,
}Expand description
This struct holds Database Credentials returned by vault
Fields
username: StringThe username to use when logging in to the database
password: StringThe password to use when logging in to the database
duration: DurationThe duration for which these credentials are valid for