pub struct ApproleOptions {Show 14 fields
pub bind_secret_id: Option<bool>,
pub secret_id_bound_cidrs: Option<Vec<String>>,
pub secret_id_num_uses: Option<u64>,
pub secret_id_ttl: Option<String>,
pub enable_local_secret_ids: Option<bool>,
pub token_ttl: Option<u64>,
pub token_max_ttl: Option<u64>,
pub token_policies: Option<Vec<String>>,
pub token_bound_cidrs: Option<Vec<String>>,
pub token_explicit_max_ttl: Option<u64>,
pub token_no_default_policy: Option<bool>,
pub token_num_uses: Option<u64>,
pub token_period: Option<u64>,
pub token_type: Option<String>,
}Expand description
Struct used for configuring an Approle-Role, contains all the options that are possible to set on said Role
Fields
bind_secret_id: Option<bool>If the secret_id is required to be present when logging in
secret_id_bound_cidrs: Option<Vec<String>>Specifies blocks of IP-addresses that can use this role
secret_id_num_uses: Option<u64>The Number of times a single Secret-ID can be used for login. 0 means unlimited
secret_id_ttl: Option<String>The TTL of a Secret-ID
Example-Value: 30m
enable_local_secret_ids: Option<bool>If the Secret-IDs generated for this role should be cluster local.
Can’t be changed after the Role has been created
token_ttl: Option<u64>The TTL of the generated Tokens in seconds
token_max_ttl: Option<u64>The maximum TTL of generated Tokens in seconds
token_policies: Option<Vec<String>>The Policies assigned to the generated Tokens
token_bound_cidrs: Option<Vec<String>>Specifies blocks of IP-addresses that can authenticate using this role and ties the tokens to these blocks as well
token_explicit_max_ttl: Option<u64>Sets an explicit maximum TTL after which every token will expire even if it was renewed before
token_no_default_policy: Option<bool>If the default Policy should not be set generated tokens
token_num_uses: Option<u64>The maximum Number of uses per generated Token, in it’s lifetime
token_period: Option<u64>The Period, if any, of the Tokens
token_type: Option<String>The Type of Token that should be generated