pub struct Configuration {
pub cas_required: Option<bool>,
pub delete_version_after: Option<String>,
pub max_versions: Option<u32>,
}Expand description
Configuration describes the configuration for a single kv2-mount
Fields
cas_required: Option<bool>Whether or not all keys are required to have the ‘cas’ option set when updating/writing to them
delete_version_after: Option<String>If set, this specifies the duration for which a version is held, older versions than described will be dropped
max_versions: Option<u32>The Number of Versions that should be kept at any given time if this number is exceeded, the oldest versions are dropped